This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: Fix comment in tree.h


Daniel Jacobowitz wrote:
> I'm guessing it was supposed to be "Nonzero _in_ a _DECL".
> 
> 
>>-/* Nonzero if a _DECL means that the name of this decl should be ignored
>>+/* Nonzero means that the name of the _DECL should be ignored
>>    for symbolic debug purposes.  */
>> #define DECL_IGNORED_P(NODE) (DECL_CHECK (NODE)->decl.ignored_flag)

Looking at tree.h again, I found the same phrasing for DECL_IN_SYSTEM_HEADER.
 While the comment dates from rev 1.1 as well, the definition of this macro
was changed by kenner in rev 1.288, letting the comment untouched, so I'm even
less sure that I'm not missing something WRT to the grammar, either that of
gcc's trees or of the English language.

Anyway, updated patch below.  This time I chose a wording closer to the other
definitions in tree.h.  Ok?

- Tobi

2003-03-12  Tobias Schl"uter  <tobias.schlueter@physik.uni-muenchen.de>

	* tree.h (DECL_IGNORED_P, DECL_IN_SYSTEM_HEADER): Clarify comments.

Index: tree.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree.h,v
retrieving revision 1.700
diff -u -p -r1.700 tree.h
--- tree.h      8 Mar 2005 13:57:01 -0000       1.700
+++ tree.h      12 Mar 2005 22:04:48 -0000
@@ -2059,8 +2059,8 @@ struct tree_binfo GTY (())
 #define DECL_FROM_INLINE(NODE) (DECL_ABSTRACT_ORIGIN (NODE) != NULL_TREE \
                                && DECL_ABSTRACT_ORIGIN (NODE) != (NODE))

-/* Nonzero if a _DECL means that the name of this decl should be ignored
-   for symbolic debug purposes.  */
+/* Nonzero for a given ..._DECL node means that the name of this node should
+   be ignored for symbolic debug purposes.  */
 #define DECL_IGNORED_P(NODE) (DECL_CHECK (NODE)->decl.ignored_flag)

 /* Nonzero for a given ..._DECL node means that this node represents an
@@ -2071,8 +2071,8 @@ struct tree_binfo GTY (())
    any code or allocate any data space for such instances.  */
 #define DECL_ABSTRACT(NODE) (DECL_CHECK (NODE)->decl.abstract_flag)

-/* Nonzero if a _DECL means that no warnings should be generated just
-   because this decl is unused.  */
+/* Nonzero for a given ..._DECL node means that no warnings should be
+   generated just because this node is unused.  */
 #define DECL_IN_SYSTEM_HEADER(NODE) \
   (DECL_CHECK (NODE)->decl.in_system_header_flag)



Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]